@@ -102,8 +102,8 @@ void usage(char *progname)
 
 	print_usage_title(progname);
 	fprintf(stderr, _("Options are:\n"
-			  "[ -A ] [ -b ] [ -B ] [ -C ] [ -d ] [ -h ] [ -m ] [ -p ] [ -q ] [ -r ] [ -R ]\n"
-			  "[ -S ] [ -t ] [ -u [ ALL ] ] [ -v ] [ -V ] [ -w ] [ -W ] [ -y ]\n"
+			  "[ -A ] [ -b ] [ -B ] [ -C ] [ -d ] [ -h ] [ -m ] [ -p ] [ -q ] [ -r ]\n"
+			  "[ -R ] [ -S ] [ -t ] [ -u [ ALL ] ] [ -v ] [ -V ] [ -w ] [ -W ] [ -y ]\n"
 			  "[ -I { <int> [,...] | SUM | ALL | XALL } ] [ -P { <cpu> [,...] | ALL } ]\n"
 			  "[ -n { <keyword> [,...] | ALL } ]\n"
 			  "[ -o [ <filename> ] | -f [ <filename> ] ]\n"
@@ -1014,7 +1014,7 @@ void read_stats(void)
 			    NO_RESET, ALL_ACTIVITIES);
 
 		if (record_hdr[curr].record_type == R_LAST_STATS) {
-			/* File rotation is happening: re-read header data sent by sadc */
+			/* File rotation is happening: Re-read header data sent by sadc */
 			read_header_data();
 			allocate_structures(act);
 		}
